@@ -35,22 +35,24 @@ def callRequest(endpoint,*args,**kwargs):
   url = getEndpointUrl(endpoint)
   return postRequest(url,kwargs)
 def getMetaData(address):
-  return solcatcherPostRequest('tokenmetadata',**{"address":address})
+  return solcatcherPostRequest('getMetaData',**{"address":address})
 def getSignaturesForAddress(address, limit=10, before=None, after=None, finalized=True):
-  return solcatcherPostRequest('signaturesforaddress',address=address, limit=limit, before=before, after=after, finalized=finalized)
+  return solcatcherPostRequest('getSignaturesForAddress',address=address, limit=limit, before=before, after=after, finalized=finalized)
 def getTransaction(signature):
-  return solcatcherPostRequest('gettransaction',**{"signature":signature})
+  return solcatcherPostRequest('getTransaction',**{"signature":signature})
 def getAccountInfo(account):
-  return solcatcherPostRequest('accountinfo',**{"account":account})
+  return solcatcherPostRequest('getAccountInfo',**{"account":account})
 def getTokenAccountBalance(account,mint):
-  return solcatcherPostRequest('tokenaccountbalance',**{"account":account,"mint":mint})
+  return solcatcherPostRequest('getTokenAccountBalance',**{"account":account,"mint":mint})
 def getTokenAccountByOwner(account,mint):
-  return solcatcherPostRequest('tokenaccountsbyowner',**{"account":account,"mint":mint})
+  return solcatcherPostRequest('getTokenAccountByOwner',**{"account":account,"mint":mint})
 def getPoolInfo(address=None,signature=None,txData=None):
   return solcatcherPostRequest('getpoolinfo',**{"address":address,"signature":signature,"txData":txData})
 def getGenesisSignature(address, limit=1000, before=None, after=None, finalized=True):
-  return solcatcherPostRequest('getgenesistransaction',address=address, limit=limit, before=before, after=after, finalized=finalized)
+  return solcatcherPostRequest('getGenesisSignature',address=address, limit=limit, before=before, after=after, finalized=finalized)
 def getTxnTypeFromMint(address):
-  return solcatcherPostRequest('gettxntypefrommint',address=address)
+  return solcatcherPostRequest('getTxnTypeFromMint',address=address)
 def getLatestBlockHash():
-  return solcatcherPostRequest('getlatestblockhash')
+  return solcatcherPostRequest('getLatestBlockHash')
+def sendTransaction(txn,preflightCommitment="finalized",skipPreflight=None):
+  'sendTransaction',{"txn":txn,"preflightCommitment":preflightCommitmentpreflightCommitment,"skipPreflight":skipPreflight or opts.skip_preflight})
